/*
 *
 * nucleo/gl/window/_events.H --
 *
 * Copyright (C) Nicolas Roussel
 *
 * See the file LICENSE for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

// This file is for nucleo internal use only

EVENTDEF(configure,(1 << 0))
EVENTDEF(expose,(1 << 1))
EVENTDEF(destroy,(1 << 2))
EVENTDEF(enter,(1 << 3))
EVENTDEF(leave,(1 << 4))
EVENTDEF(keyPress,(1 << 5))
EVENTDEF(keyRelease,(1 << 6))
EVENTDEF(buttonPress,(1 << 7))
EVENTDEF(buttonRelease,(1 << 8))
EVENTDEF(pointerMotion,(1 << 9))
EVENTDEF(wheelMotion,(1 << 10))
