#ifndef n_AppUtils_H
#define n_AppUtils_H

/*
 *
 * nucleo/utils/AppUtils.H --
 *
 * Copyright (C) Nicolas Roussel
 *
 * See the file LICENSE for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdarg.h>

#include <string>

namespace nucleo {

  int parseCommandLine(int argc, char** argv,
				   const char* oformat, const char* pformat,
				   ...) ;

  std::string getResourceDirectory(void) ;

}

#endif
