/*
 *
 * nucleo/gl/window/_macos2keysym.H --
 *
 * Copyright (C) Nicolas Roussel
 *
 * See the file LICENSE for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

// This file is for nucleo internal use only

// --------------------------------------------------
// Function keys: charCode=16, must check keyCode

// KEYTRANS(16,XK_F1,"<F1>")
// KEYTRANS(16,XK_F2,"<F2>")
// KEYTRANS(16,XK_F3,"<F3>")
// KEYTRANS(16,XK_F4,"<F4>")
// KEYTRANS(16,XK_F5,"<F5>")
// KEYTRANS(16,XK_F6,"<F6>")
// KEYTRANS(16,XK_F7,"<F7>")
// KEYTRANS(16,XK_F8,"<F8>")
// KEYTRANS(16,XK_F9,"<F9>")
// KEYTRANS(16,XK_F10,"<F10>")
// KEYTRANS(16,XK_F11,"<F11>")
// KEYTRANS(16,XK_F12,"<F12>")

// --------------------------------------------------
// Modifier keys

// KEYTANS("",XK_Meta_L,"<LeftMeta>")
// KEYTANS("",XK_Shift_L,"<LeftShift>")
// KEYTANS("",XK_Control_L,"<LeftControl>")
// KEYTANS("",XK_Alt_L,"<LeftAlt>")
// KEYTANS("",XK_Super_L,"<LeftSuper>")
// KEYTANS("",XK_Hyper_L,"<LeftHyper>")

// KEYTANS("",XK_Meta_R,"<RightMeta>")
// KEYTANS("",XK_Shift_R,"<RightShift>")
// KEYTANS("",XK_Control_R,"<RightControl>")
// KEYTANS("",XK_Alt_R,"<RightAlt>")
// KEYTANS("",XK_Super_R,"<RightSuper>")
// KEYTANS("",XK_Hyper_R,"<RightHyper>")

// KEYTANS("",XK_Caps_Lock,"<CapsLock>")
// KEYTRANS("",XK_Num_Lock,"<NumLock>")

// KEYTANS("",XK_Shift_Lock,"<ShiftLock>")

// --------------------------------------------------

KEYTRANS('0',XK_0,"0")
KEYTRANS('1',XK_1,"1")
KEYTRANS('2',XK_2,"2")
KEYTRANS('3',XK_3,"3")
KEYTRANS('4',XK_4,"4")
KEYTRANS('5',XK_5,"5")
KEYTRANS('6',XK_6,"6")
KEYTRANS('7',XK_7,"7")
KEYTRANS('8',XK_8,"8")
KEYTRANS('9',XK_9,"9")

KEYTRANS('A',XK_A,"A")
KEYTRANS('B',XK_B,"B")
KEYTRANS('C',XK_C,"C")
KEYTRANS('D',XK_D,"D")
KEYTRANS('E',XK_E,"E")
KEYTRANS('F',XK_F,"F")
KEYTRANS('G',XK_G,"G")
KEYTRANS('H',XK_H,"H")
KEYTRANS('I',XK_I,"I")
KEYTRANS('J',XK_J,"J")
KEYTRANS('K',XK_K,"K")
KEYTRANS('L',XK_L,"L")
KEYTRANS('M',XK_M,"M")
KEYTRANS('N',XK_N,"N")
KEYTRANS('O',XK_O,"O")
KEYTRANS('P',XK_P,"P")
KEYTRANS('Q',XK_Q,"Q")
KEYTRANS('R',XK_R,"R")
KEYTRANS('S',XK_S,"S")
KEYTRANS('T',XK_T,"T")
KEYTRANS('U',XK_U,"U")
KEYTRANS('V',XK_V,"V")
KEYTRANS('W',XK_W,"W")
KEYTRANS('X',XK_X,"X")
KEYTRANS('Y',XK_Y,"Y")
KEYTRANS('Z',XK_Z,"Z")

KEYTRANS('a',XK_a,"a")
KEYTRANS('b',XK_b,"b")
KEYTRANS('c',XK_c,"c")
KEYTRANS('d',XK_d,"d")
KEYTRANS('e',XK_e,"e")
KEYTRANS('f',XK_f,"f")
KEYTRANS('g',XK_g,"g")
KEYTRANS('h',XK_h,"h")
KEYTRANS('i',XK_i,"i")
KEYTRANS('j',XK_j,"j")
KEYTRANS('k',XK_k,"k")
KEYTRANS('l',XK_l,"l")
KEYTRANS('m',XK_m,"m")
KEYTRANS('n',XK_n,"n")
KEYTRANS('o',XK_o,"o")
KEYTRANS('p',XK_p,"p")
KEYTRANS('q',XK_q,"q")
KEYTRANS('r',XK_r,"r")
KEYTRANS('s',XK_s,"s")
KEYTRANS('t',XK_t,"t")
KEYTRANS('u',XK_u,"u")
KEYTRANS('v',XK_v,"v")
KEYTRANS('w',XK_w,"w")
KEYTRANS('x',XK_x,"x")
KEYTRANS('y',XK_y,"y")
KEYTRANS('z',XK_z,"z")

// --------------------------------------------------

KEYTRANS(' ',XK_space," ")
KEYTRANS('!',XK_exclam,"!")
KEYTRANS('"',XK_quotedbl,"\"")
KEYTRANS('#',XK_numbersign,"#")
KEYTRANS('$',XK_dollar,"$")
KEYTRANS('%',XK_percent,"%")
KEYTRANS('&',XK_ampersand,"&")
KEYTRANS('\'',XK_apostrophe,"'")
KEYTRANS('(',XK_parenleft,"(")
KEYTRANS(')',XK_parenright,")")
KEYTRANS('*',XK_asterisk,"*")
KEYTRANS('+',XK_plus,"+")
KEYTRANS(',',XK_comma,",")
KEYTRANS('-',XK_minus,"-")
KEYTRANS('.',XK_period,".")
KEYTRANS('/',XK_slash,"/")
KEYTRANS(':',XK_colon,":")
KEYTRANS(';',XK_semicolon,";")
KEYTRANS('<',XK_less,"<")
KEYTRANS('=',XK_equal,"=")
KEYTRANS('>',XK_greater,">")
KEYTRANS('?',XK_question,"?")
KEYTRANS('@',XK_at,"@")
KEYTRANS('[',XK_bracketleft,"[")
KEYTRANS('\\',XK_backslash,"\\")
KEYTRANS(']',XK_bracketright,"]")
KEYTRANS('_',XK_underscore,"_")
KEYTRANS('`',XK_grave,"`")
KEYTRANS('{',XK_braceleft,"{")
KEYTRANS('|',XK_bar,"|")
KEYTRANS('}',XK_braceright,"}")
KEYTRANS('~',XK_asciitilde,"~")
KEYTRANS('£',XK_sterling,"£")

// --------------------------------------------------

KEYTRANS(13,XK_Return,"<Return>")
KEYTRANS(27,XK_Escape,"<Escape>")
KEYTRANS(9,XK_Tab,"<Tab>")

KEYTRANS(3,XK_Linefeed,"<LineFeed>")
KEYTRANS(8,XK_BackSpace,"<BackSpace>")
KEYTRANS(127,XK_Delete,"<Delete>")
KEYTRANS(1,XK_Home,"<Home>")
KEYTRANS(4,XK_End,"<End>")
KEYTRANS(28,XK_Left,"<Left>")
KEYTRANS(29,XK_Right,"<Right>")
KEYTRANS(30,XK_Up,"<Up>")
KEYTRANS(31,XK_Down,"<Down>")
KEYTRANS(11,XK_Page_Up,"<PageUp>")
KEYTRANS(12,XK_Page_Down,"<PageDown>")

KEYTRANS(-92,XK_paragraph,"§")
KEYTRANS(-113,XK_egrave,"è")
KEYTRANS(-114,XK_eacute,"é")
KEYTRANS(-120,XK_agrave,"à")
KEYTRANS(-115,XK_ccedilla,"ç")
KEYTRANS(-99,XK_ugrave,"ù")

// --------------------------------------------------

KEYTRANS('ê',XK_ecircumflex,"ê")
KEYTRANS('î',XK_icircumflex,"î")
KEYTRANS('ï',XK_idiaeresis,"ï")
KEYTRANS('ô',XK_ocircumflex,"ô")
KEYTRANS('û',XK_ucircumflex,"û")

// KEYTRANS('¡',XK_exclamdown,"¡")
// KEYTRANS('á',XK_acute,"á")
// KEYTRANS('¿',XK_questiondown,"¿")
// KEYTRANS('À',XK_Agrave,"À")
// KEYTRANS('Á',XK_Aacute,"Á")
// KEYTRANS('Â',XK_Acircumflex,"Â")
// KEYTRANS('Ã',XK_Atilde,"Ã")
// KEYTRANS('Ä',XK_Adiaeresis,"Ä")
// KEYTRANS('Ç',XK_Ccedilla,"Ç")
// KEYTRANS('È',XK_Egrave,"È")
// KEYTRANS('É',XK_Eacute,"É")
// KEYTRANS('Ê',XK_Ecircumflex,"Ê")
// KEYTRANS('Ë',XK_Ediaeresis,"Ë")
// KEYTRANS('Ì',XK_Igrave,"Ì")
// KEYTRANS('Í',XK_Iacute,"Í")
// KEYTRANS('Î',XK_Icircumflex,"Î")
// KEYTRANS('Ï',XK_Idiaeresis,"Ï")
// KEYTRANS('Ñ',XK_Ntilde,"Ñ")
// KEYTRANS('Ò',XK_Ograve,"Ò")
// KEYTRANS('Ó',XK_Oacute,"Ó")
// KEYTRANS('Ô',XK_Ocircumflex,"Ô")
// KEYTRANS('Õ',XK_Otilde,"Õ")
// KEYTRANS('Ö',XK_Odiaeresis,"Ö")
// KEYTRANS('Ù',XK_Ugrave,"Ù")
// KEYTRANS('Ú',XK_Uacute,"Ú")
// KEYTRANS('Û',XK_Ucircumflex,"Û")
// KEYTRANS('Ü',XK_Udiaeresis,"Ü")
// KEYTRANS('Ý',XK_Yacute,"Ý")
// KEYTRANS('á',XK_aacute,"á")
// KEYTRANS('â',XK_acircumflex,"â")
// KEYTRANS('ã',XK_atilde,"ã")
// KEYTRANS('ä',XK_adiaeresis,"ä")
// KEYTRANS('ë',XK_ediaeresis,"ë")
// KEYTRANS('ì',XK_igrave,"ì")
// KEYTRANS('í',XK_iacute,"í")
// KEYTRANS('ñ',XK_ntilde,"ñ")
// KEYTRANS('ò',XK_ograve,"ò")
// KEYTRANS('ó',XK_oacute,"ó")
// KEYTRANS('õ',XK_otilde,"õ")
// KEYTRANS('ö',XK_odiaeresis,"ö")
// KEYTRANS('ø',XK_oslash,"ø")
// KEYTRANS('ú',XK_uacute,"ú")
// KEYTRANS('ü',XK_udiaeresis,"ü")
// KEYTRANS('ÿ',XK_ydiaeresis,"ÿ")
// KEYTRANS('ý',XK_yacute,"ý")

// --------------------------------------------------
// What about these?

// KEYTRANS('',XK_Clear,"")
// KEYTRANS('',XK_Pause,"")
// KEYTRANS('',XK_Scroll_Lock,"")
// KEYTRANS('',XK_Sys_Req,"")
// KEYTRANS('',XK_asciicircum,"")
// KEYTRANS('',XK_nobreakspace,"")
// KEYTRANS('',XK_cent,"")
// KEYTRANS('',XK_currency,"")
// KEYTRANS('',XK_yen,"")
// KEYTRANS('',XK_brokenbar,"")
// KEYTRANS('',XK_section,"")
// KEYTRANS('',XK_diaeresis,"")
// KEYTRANS('',XK_copyright,"")
// KEYTRANS('',XK_ordfeminine,"")
// KEYTRANS('',XK_guillemotleft,"")
// KEYTRANS('',XK_notsign,"")
// KEYTRANS('',XK_hyphen,"")
// KEYTRANS('',XK_registered,"")
// KEYTRANS('',XK_macron,"")
// KEYTRANS('',XK_degree,"")
// KEYTRANS('',XK_plusminus,"")
// KEYTRANS('',XK_twosuperior,"")
// KEYTRANS('',XK_threesuperior,"")
// KEYTRANS('',XK_Aring,"")
// KEYTRANS('',XK_AE,"")
// KEYTRANS('',XK_mu,"")
// KEYTRANS('',XK_periodcentered,"")
// KEYTRANS('',XK_cedilla,"")
// KEYTRANS('',XK_onesuperior,"")
// KEYTRANS('',XK_masculine,"")
// KEYTRANS('',XK_guillemotright,"")
// KEYTRANS('',XK_onequarter,"")
// KEYTRANS('',XK_onehalf,"")
// KEYTRANS('',XK_threequarters,"")
// KEYTRANS('',XK_ETH,"")
// KEYTRANS('',XK_Eth,"")
// KEYTRANS('',XK_multiply,"")
// KEYTRANS('',XK_Ooblique,"")
// KEYTRANS('',XK_THORN,"")
// KEYTRANS('',XK_ssharp,"")
// KEYTRANS('',XK_aring,"")
// KEYTRANS('',XK_ae,"")
// KEYTRANS('',XK_eth,"")
// KEYTRANS('',XK_division,"")
// KEYTRANS('',XK_thorn,"")
