#ifndef n_NetworkUtils_H
#define n_NetworkUtils_H

/*
 *
 * nucleo/network/Utils.H --
 *
 * Copyright (C) Nicolas Roussel
 *
 * See the file LICENSE for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <sys/types.h>
#include <netinet/in.h>

namespace nucleo {

  struct in_addr* resolveAddress(const char *address) ;

}

#endif
