#ifndef n_Service_H
#define n_Service_H

/*
 *
 * nucleo/network/rdv/Service.H --
 *
 * Copyright (C) Nicolas Roussel
 *
 * See the file LICENSE for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <string>
#include <map>

namespace nucleo {

  typedef std::map<std::string, std::string> TextRecords ;

  struct Service {
    
    // Minimum service information
    std::string type ;
    std::string name ;
    std::string domain ;
    
  // Additional information (obtained when the service is resolved)
    std::string ipaddr ;
    int port ;
    TextRecords textRecords ;
    
  } ;
  
}

#endif
